Release 0.1.4 (02/12/2011)
================================

* new backend: pygtk
* set bounding box in imagemagick call 
* more test
* using EasyProcess
* plugin system changed

Release 0.1.3 (02/02/2011)
================================

* First release.

